@@ -1,9 +1,6 @@
 ################################################################################
 # Location: ...................... <user defined location>/eBay
 # File: .......................... API.pm
-# Original Author: ............... Jeff Nokes
-# Last Modifed By: ............... Bob Bradley / Jeff Nokes
-# Last Modified: ................. 03/30/2007 @ 23:09
 #
 # Description
 #
@@ -40,7 +37,7 @@
   # none
 
 # Globals
-  our $VERSION = '0.22';
+  our $VERSION = '0.23';
 
 # Lexicals
   # none
@@ -250,12 +247,12 @@ The package includes tools to auto generate all classes needed to
 invoke any published eBay XML API web service, including accessing all
 data components accepted and delivered by the web services.
 
-   lib/eBay/API/XML/Tools/CodeGen/XSD
+   lib/eBay/API/XML/tools/codegen/xsd
 
 There is also a tool to generate indexed HTML documenation for every package
 included in this library, or generated by this library.
 
-   lib/eBay/API/XML/Tools/Doc
+   lib/eBay/API/XML/tools/doc
 
 =head3 Auto Generation of Call & Data type Classes
 
@@ -277,7 +274,7 @@ transparently keep up with these enhancements and make them directly
 available to your API-enabled applications as new versions of the eBay
 API become available.
 
-Consult the README file in lib/eBay/API/XML/Tools/CodeGen/XSD for
+Consult the README file in lib/eBay/API/XML/tools/codegen/xsd for
 instructions on how to update your generated eBay XML API web services
 class library.
 
@@ -303,7 +300,7 @@ the generated classes only exists in POD format.
 
 Using the genhtmldoc.pl tool (mentioned above in the Tools section),
 you can create a library of indexed HTML documentation.  Consult the README
-file in lib/eBay/API/XML/Tools/Doc for details on how to compile and access
+file in lib/eBay/API/XML/tools/doc for details on how to compile and access
 HTML manual pages for the generated classes from a web browser.
 
 
@@ -1486,25 +1483,8 @@ AmountType has two properties: value and currencyID.
 
 =head1 SEE ALSO
 
-=head2 http://developer.ebay.com
-
-    The eBay Developer Zone / Code Base
-
-=head2 https://ebay-perl-api-sdk.codebase.ebay.com
-
-    The above link will take you to the official project page for the Perl
-    eBay API SDK.  You will most likely have to register with the eBay
-    developers zone in order to file bugs, suggest features, provide patches,
-    provide feedback, etc.  It is here where all communication and support
-    for this module will be handled.  Please be patient for any responses as
-    there is a B<VERY> small team internal at eBay who is maintaining this
-    SDK, and we have other responsibilities as well.
-
-=item * Project Homepage:  https://ebay-perl-api-sdk.codebase.ebay.com
-
-=item * Project Mailing Lists:  https://ebay-perl-api-sdk.codebase.ebay.com/servlets/ProjectMailingListList
-
-=item * Project Issue Tracker:  https://ebay-perl-api-sdk.codebase.ebay.com/servlets/ProjectIssues
+http://developer.ebay.com
+https://ebay-perl-api-sdk.codebase.ebay.com
 
 
 
@@ -1514,13 +1494,25 @@ AmountType has two properties: value and currencyID.
 
 in alphabetical order:
 
-=item * Robert Bradley
+=item *
 
-=item * Mike Evans
+Robert Bradley
 
-=item * Milenko Milanovic
+=item *
 
-=item * Jeff Nokes
+Mike Evans
+
+=item *
+
+Milenko Milanovic
+
+=item *
+
+Jeff Nokes
+
+=item *
+
+perl@ebay.com
 
 
 
